@@ -36,7 +36,7 @@ it and/or modify it under the same terms as Perl itself.
 
 =head1 VERSION
 
-$Revision: 4.103 $ $Date: 1999/02/09 03:32:49 $
+$Revision$ $Date$
 
 =cut
 
@@ -45,9 +45,11 @@ use vars qw(@ISA $VERSION);
 
 @ISA = qw(MIME::Decoder);
 
-# The package version, both in 1.23 style *and* usable by MakeMaker:
-$VERSION = substr q$Revision: 4.103 $, 10;
+### The package version, both in 1.23 style *and* usable by MakeMaker:
+$VERSION = "5.420_01";
 
+### Buffer length:
+my $BUFLEN = 8192;
 
 #------------------------------
 #
@@ -57,10 +59,10 @@ sub decode_it {
     my ($self, $in, $out) = @_;
 
     my ($buf, $nread) = ('', 0);
-    while ($nread = $in->read($buf, 4096)) {
+    while ($nread = $in->read($buf, $BUFLEN)) {
 	$out->print($buf);
     }
-    defined($nread) or return undef;      # check for error
+    defined($nread) or return undef;      ### check for error
     1;
 }
 
@@ -72,10 +74,10 @@ sub encode_it {
     my ($self, $in, $out) = @_;
 
     my ($buf, $nread) = ('', 0);
-    while ($nread = $in->read($buf, 4096)) {
+    while ($nread = $in->read($buf, $BUFLEN)) {
 	$out->print($buf);
     }
-    defined($nread) or return undef;      # check for error
+    defined($nread) or return undef;      ### check for error
     1;
 }
 
