@@ -45,7 +45,7 @@ it and/or modify it under the same terms as Perl itself.
 
 =head1 VERSION
 
-$Revision: 4.105 $ $Date: 1999/02/09 03:32:49 $
+$Revision$ $Date$
 
 =cut
 
@@ -55,14 +55,13 @@ use vars qw(@ISA $VERSION $ZIP $UNZIP);
 use MIME::Decoder;
 use MIME::Base64;
 use MIME::Decoder::Base64;
-use MIME::ToolUtils qw(tmpopen whine);
-use IO::Wrap;
+use MIME::Tools qw(tmpopen whine);
 
 # Inheritance:
 @ISA = qw(MIME::Decoder::Base64);
 
 # The package version, both in 1.23 style *and* usable by MakeMaker:
-$VERSION = substr q$Revision: 4.105 $, 10;
+$VERSION = "5.420_01";
 
 # How to compress stdin to stdout:
 $GZIP   = "gzip -c";
@@ -79,7 +78,7 @@ sub decode_it {
     my ($self, $in, $out) = @_;
 
     # Open a temp file (assume the worst, that this is a big stream):
-    my $tmp = wraphandle(tmpopen() || die "can't get temp file");
+    my $tmp = tmpopen() || die "can't get temp file";
 
     # Stage 1: decode the base64'd stream into zipped data:
     $self->SUPER::decode_it($in, $tmp)    or die "base64 decoding failed!";
@@ -98,7 +97,7 @@ sub encode_it {
     whine "Encoding ", $self->encoding, " is not standard MIME!"; 
     
     # Open a temp file (assume the worst, that this is a big stream):
-    my $tmp = wraphandle(tmpopen() || die "can't get temp file");
+    my $tmp = tmpopen() || die "can't get temp file";
   
     # Stage 1: zip the raw data:
     $self->filter($in, $tmp, $GZIP)       or die "gzip encoding failed!";
