@@ -10,6 +10,9 @@ MIME::Decoder::UU - decode a "uuencoded" stream
 
 A generic decoder object; see L<MIME::Decoder> for usage.
 
+Also supports a preamble() method to recover text before
+the uuencoded portion of the stream.
+
 
 =head1 DESCRIPTION
 
@@ -33,7 +36,7 @@ it and/or modify it under the same terms as Perl itself.
 
 =head1 VERSION
 
-$Revision: 4.103 $ $Date: 1999/02/09 03:32:50 $
+$Revision$ $Date$
 
 =cut
 
@@ -41,12 +44,12 @@ $Revision: 4.103 $ $Date: 1999/02/09 03:32:50 $
 require 5.002;
 use vars qw(@ISA $VERSION);
 use MIME::Decoder;
-use MIME::ToolUtils qw(whine);
+use MIME::Tools qw(whine);
 
 @ISA = qw(MIME::Decoder);
 
 # The package version, both in 1.23 style *and* usable by MakeMaker:
-$VERSION = substr q$Revision: 4.103 $, 10;
+$VERSION = "5.420_01";
 
 
 #------------------------------
@@ -56,14 +59,32 @@ $VERSION = substr q$Revision: 4.103 $, 10;
 sub decode_it {
     my ($self, $in, $out) = @_;
     my ($mode, $file);
+    my @preamble;
 
-    # Find beginning...
+    ### Init:
+    $self->{MDU_Preamble} = \@preamble;
+    $self->{MDU_Mode} = undef;
+    $self->{MDU_File} = undef;
+
+    ### Find beginning...
+    local $_;
     while (defined($_ = $in->getline)) {
-	last if ($mode, $file) = /^begin\s*(\d*)\s*(\S*)/; 
+	if (/^begin(.*)/) {        ### found it: now decode it...
+	    my $modefile = $1;
+	    if ($modefile =~ /^(\s+(\d+))?(\s+(.*?\S))?\s*\Z/) {
+		($mode, $file) = ($2, $4);
+	    }
+	    last;                  ### decoded or not, we're done
+	}
+	push @preamble, $_;
     }
     die("uu decoding: no begin found\n") if !defined($_);      # hit eof!
-    
-    # Decode:
+
+    ### Store info:
+    $self->{MDU_Mode} = $mode;
+    $self->{MDU_File} = $file;
+
+    ### Decode:
     while (defined($_ = $in->getline)) {
 	last if /^end/;
 	next if /[a-z]/;
@@ -92,5 +113,39 @@ sub encode_it {
     1;
 }
 
+#------------------------------
+#
+# last_preamble
+#
+# Return the last preamble as ref to array of lines.
+# Gets reset by decode_it().
+#
+sub last_preamble {
+    my $self = shift;
+    return $self->{MDU_Preamble} || [];
+}
+
+#------------------------------
+#
+# last_mode
+#
+# Return the last mode.
+# Gets reset to undef by decode_it().
+#
+sub last_mode {
+    shift->{MDU_Mode};
+}
+
+#------------------------------
+#
+# last_filename
+#
+# Return the last filename.
+# Gets reset by decode_it().
+#
+sub last_filename {
+    shift->{MDU_File} || [];
+}
+
 #------------------------------
 1;
