@@ -8,23 +8,31 @@ MIME::Words - deal with RFC-1522 encoded words
 
 =head1 SYNOPSIS
 
+Before reading further, you should see L<MIME::Tools> to make sure that 
+you understand where this module fits into the grand scheme of things.
+Go on, do it now.  I'll wait.  
+
+Ready?  Ok...
+
+
     use MIME::Words qw(:all);   
      
-    # Decode the string into another string, forgetting the charsets:
+    ### Decode the string into another string, forgetting the charsets:
     $decoded = decode_mimewords(
           'To: =?ISO-8859-1?Q?Keld_J=F8rn_Simonsen?= <keld@dkuug.dk>',
           );
     
-    # Split string into array of decoded [DATA,CHARSET] pairs:
+    ### Split string into array of decoded [DATA,CHARSET] pairs:
     @decoded = decode_mimewords(
           'To: =?ISO-8859-1?Q?Keld_J=F8rn_Simonsen?= <keld@dkuug.dk>',
           );
      
-    # Encode a single unsafe word:
+    ### Encode a single unsafe word:
     $encoded = encode_mimeword("\xABFran\xE7ois\xBB");
     
-    # Encode a string, trying to find the unsafe words inside it: 
-    $encoded = encode_mimewords("Me and \xABFran\xE7ois\xBB at the beach");
+    ### Encode a string, trying to find the unsafe words inside it: 
+    $encoded = encode_mimewords("Me and \xABFran\xE7ois\xBB in town");
+
 
 
 =head1 DESCRIPTION
@@ -58,11 +66,11 @@ Latin characters with 7 bit sequences /o and 'e):
 
 require 5.001;
 
-# Pragmas:
+### Pragmas:
 use strict;
 use vars qw($VERSION @EXPORT_OK %EXPORT_TAGS @ISA);
 
-# Exporting:
+### Exporting:
 use Exporter;
 %EXPORT_TAGS = (all => [qw(decode_mimewords
 			   encode_mimeword
@@ -70,10 +78,10 @@ use Exporter;
 			   )]);
 Exporter::export_ok_tags('all');
 
-# Inheritance:
+### Inheritance:
 @ISA = qw(Exporter);
 
-# Other modules:
+### Other modules:
 use MIME::Base64;
 use MIME::QuotedPrint;
 
@@ -85,10 +93,10 @@ use MIME::QuotedPrint;
 #
 #------------------------------
 
-# The package version, both in 1.23 style *and* usable by MakeMaker:
-$VERSION = substr q$Revision: 4.104 $, 10;
+### The package version, both in 1.23 style *and* usable by MakeMaker:
+$VERSION = "5.420_01";
 
-# Nonprintables (controls + x7F + 8bit):
+### Nonprintables (controls + x7F + 8bit):
 my $NONPRINT = "\\x00-\\x1F\\x7F-\\xFF"; 
 
 
@@ -99,8 +107,8 @@ my $NONPRINT = "\\x00-\\x1F\\x7F-\\xFF";
 #     almost, but not exactly, quoted-printable.  :-P
 sub _decode_Q {
     my $str = shift;
-    $str =~ s/=([\da-fA-F]{2})/pack("C", hex($1))/ge;  # RFC-1522, Q rule 1
     $str =~ s/_/\x20/g;                                # RFC-1522, Q rule 2
+    $str =~ s/=([\da-fA-F]{2})/pack("C", hex($1))/ge;  # RFC-1522, Q rule 1
     $str;
 }
 
@@ -109,7 +117,7 @@ sub _decode_Q {
 #     almost, but not exactly, quoted-printable.  :-P
 sub _encode_Q {
     my $str = shift;
-    $str =~ s{[\?\=\_$NONPRINT]}{sprintf("=%02X", ord($&))}eog;
+    $str =~ s{([_\?\=$NONPRINT])}{sprintf("=%02X", ord($1))}eog;
     $str;
 }
 
@@ -124,7 +132,7 @@ sub _decode_B {
 #     Private: used by _decode_header() to decode "B" encoding.
 sub _encode_B {
     my $str = shift;
-    encode_base64($str);
+    encode_base64($str, '');
 }
 
 
@@ -133,6 +141,7 @@ sub _encode_B {
 
 =item decode_mimewords ENCODED, [OPTS...]
 
+I<Function.>
 Go through the string looking for RFC-1522-style "Q"
 (quoted-printable, sort of) or "B" (base64) encoding, and decode them.
 
@@ -146,9 +155,12 @@ CHARSET of C<undef>.
         print "", ($_[1] || 'US-ASCII'), ": ", $_[0], "\n";
     }
 
-B<In a scalar context,> joins the "data" elements of the above list together,
-and returns that.  This is information-lossy, but if you know that
-all charsets in the ENCODED string are identical, it might be useful to you.
+B<In a scalar context,> joins the "data" elements of the above 
+list together, and returns that.  I<Warning: this is information-lossy,>
+and probably I<not> what you want, but if you know that all charsets 
+in the ENCODED string are identical, it might be useful to you.
+(Before you use this, please see L<MIME::WordDecoder/unmime>,
+which is probably what you want.)
 
 In the event of a syntax error, $@ will be set to a description 
 of the error, but parsing will continue as best as possible (so as to
@@ -171,25 +183,25 @@ sub decode_mimewords {
     my $encstr = shift;
     my %params = @_;
     my @tokens;
-    $@ = '';           # error-return
+    $@ = '';           ### error-return
 
-    # Collapse boundaries between adjacent encoded words:
-    $encstr =~ s{(\?\=)\r?\n[ \t](\=\?)}{$1$2}gs;
+    ### Collapse boundaries between adjacent encoded words:
+    $encstr =~ s{(\?\=)\s*(\=\?)}{$1$2}gs;
     pos($encstr) = 0;
     ### print STDOUT "ENC = [", $encstr, "]\n";
 
-    # Decode:
+    ### Decode:
     my ($charset, $encoding, $enc, $dec);
     while (1) {
 	last if (pos($encstr) >= length($encstr));
-	my $pos = pos($encstr);               # save it
+	my $pos = pos($encstr);               ### save it
 
-	# Case 1: are we looking at "=?..?..?="?
-	if ($encstr =~    m{\G                # from where we left off..
-			    =\?([^?]*)        # "=?" + charset +
-			     \?([bq])         #  "?" + encoding +
-			     \?([^?]+)        #  "?" + data maybe with spcs +
-			     \?=              #  "?="
+	### Case 1: are we looking at "=?..?..?="?
+	if ($encstr =~    m{\G             # from where we left off..
+			    =\?([^?]*)     # "=?" + charset +
+			     \?([bq])      #  "?" + encoding +
+			     \?([^?]+)     #  "?" + data maybe with spcs +
+			     \?=           #  "?="
 			    }xgi) {
 	    ($charset, $encoding, $enc) = ($1, lc($2), $3);
 	    $dec = (($encoding eq 'q') ? _decode_Q($enc) : _decode_B($enc));
@@ -197,8 +209,8 @@ sub decode_mimewords {
 	    next;
 	}
 
-	# Case 2: are we looking at a bad "=?..." prefix? 
-	# We need this to detect problems for case 3, which stops at "=?":
+	### Case 2: are we looking at a bad "=?..." prefix? 
+	### We need this to detect problems for case 3, which stops at "=?":
 	pos($encstr) = $pos;               # reset the pointer.
 	if ($encstr =~ m{\G=\?}xg) {
 	    $@ .= qq|unterminated "=?..?..?=" in "$encstr" (pos $pos)\n|;
@@ -206,7 +218,7 @@ sub decode_mimewords {
 	    next;
 	}
 
-	# Case 3: are we looking at ordinary text?
+	### Case 3: are we looking at ordinary text?
 	pos($encstr) = $pos;               # reset the pointer.
 	if ($encstr =~ m{\G                # from where we left off...
 			 ([\x00-\xFF]*?    #   shortest possible string,
@@ -218,7 +230,7 @@ sub decode_mimewords {
 	    next;
 	}
 
-	# Case 4: bug!
+	### Case 4: bug!
 	die "MIME::Words: unexpected case:\n($encstr) pos $pos\n\t".
 	    "Please alert developer.\n";
     }
@@ -229,15 +241,15 @@ sub decode_mimewords {
 
 =item encode_mimeword RAW, [ENCODING], [CHARSET]
 
+I<Function.>
 Encode a single RAW "word" that has unsafe characters.
+The "word" will be encoded in its entirety.
 
-    # Encode "<<Franc,ois>>":
+    ### Encode "<<Franc,ois>>":
     $encoded = encode_mimeword("\xABFran\xE7ois\xBB");
 
 You may specify the ENCODING (C<"Q"> or C<"B">), which defaults to C<"Q">.
 You may specify the CHARSET, which defaults to C<iso-8859-1>.
-    
-The "word" will be encoded in its entirety.
 
 =cut
 
@@ -253,11 +265,12 @@ sub encode_mimeword {
 
 =item encode_mimewords RAW, [OPTS]
 
+I<Function.>
 Given a RAW string, try to find and encode all "unsafe" sequences 
 of characters:
 
-    # Encode a string with some unsafe "words":
-    $encoded = encode_mimewords("Me and \xABFran\xE7ois\xBB at the beach");
+    ### Encode a string with some unsafe "words":
+    $encoded = encode_mimewords("Me and \xABFran\xE7ois\xBB");
 
 Returns the encoded string.
 Any arguments past the RAW string are taken to define a hash of options:
@@ -280,8 +293,11 @@ Name of the mail field this string will be used in.  I<Currently ignored.>
 =back
 
 B<Warning:> this is a quick-and-dirty solution, intended for character
-sets which overlap ASCII.  You may want to roll your own variant,
-using L<encoded_mimeword()>, for your application.
+sets which overlap ASCII.  B<It does not comply with the RFC-1522
+rules regarding the use of encoded words in message headers>.
+You may want to roll your own variant,
+using C<encoded_mimeword()>, for your application.
+I<Thanks to Jan Kasprzak for reminding me about this problem.>
 
 =cut
 
@@ -290,18 +306,19 @@ sub encode_mimewords {
     my $charset  = $params{Charset} || 'ISO-8859-1';
     my $encoding = lc($params{Encoding} || 'q');
 
-    # Encode any "words" with unsafe characters.
-    #    We limit such words to 18 characters, to guarantee that the 
-    #    worst-case encoding give us no more than 54 + ~10 < 75 characters
+    ### Encode any "words" with unsafe characters.
+    ###    We limit such words to 18 characters, to guarantee that the 
+    ###    worst-case encoding give us no more than 54 + ~10 < 75 characters
     my $word;
-    $rawstr =~ s{[a-zA-Z0-9\x7F-\xFF]{1,18}}{     # get next "word"
-	$word = $&;
+    $rawstr =~ s{([a-zA-Z0-9\x7F-\xFF]{1,18})}{     ### get next "word"
+	$word = $1;
 	(($word !~ /[$NONPRINT]/o) 
-	 ? $word                                          # no unsafe chars
-	 : encode_mimeword($word, $encoding, $charset));  # has unsafe chars
+	 ? $word                                          ### no unsafe chars
+	 : encode_mimeword($word, $encoding, $charset));  ### has unsafe chars
     }xeg;
     $rawstr;
 }
+
 1;
 __END__
 
@@ -317,6 +334,7 @@ MIME::Base64 and MIME::QuotedPrint.
 =head1 AUTHOR
 
 Eryq (F<eryq@zeegee.com>), ZeeGee Software Inc (F<http://www.zeegee.com>).
+David F. Skoll (dfs@roaringpenguin.com) http://www.roaringpenguin.com
 
 All rights reserved.  This program is free software; you can redistribute 
 it and/or modify it under the same terms as Perl itself.
@@ -325,65 +343,13 @@ Thanks also to...
 
       Kent Boortz        For providing the idea, and the baseline 
                          RFC-1522-decoding code!
-      kjj@primenet.com   For requesting that this be split into
+      KJJ at PrimeNet    For requesting that this be split into
                          its own module.
       Stephane Barizien  For reporting a nasty bug.
 
 
 =head1 VERSION
 
-$Revision: 4.104 $ $Date: 1999/02/09 03:32:39 $
+$Revision$ $Date$
 
 =cut
-
-
-#------------------------------
-# Execute simple test if run as a script.
-#------------------------------
-{ 
-  package main; no strict;
-  eval join('',<main::DATA>) || die "$@ $main::DATA" unless caller();
-}
-1;           # end the module
-__END__
-
-
-# Pick up other MIME stuff, just in case...
-BEGIN { unshift @INC, ".", "./etc", "./lib" };
-import MIME::Words;
-
-my @encs = (
-	    '=?US-ASCII?Q?Keith_Moore?= <moore@cs.utk.edu>',
-	    '=?ISO-8859-1?Q?Keld_J=F8rn_Simonsen?= <keld@dkuug.dk>',
-	    '=?ISO-8859-1?Q?Andr=E9_?= Pirard <PIRARD@vm1.ulg.ac.be>',
-	    ('=?ISO-8859-1?B?SWYgeW91IGNhbiByZWFkIHRoaXMgeW8=?='.
-	     '=?ISO-8859-2?B?dSB1bmRlcnN0YW5kIHRoZSBleGFtcGxlLg==?='.
-	     '=?US-ASCII?Q?.._cool!?='));
-foreach $enc (@encs) {
-    $x = decode_mimewords($enc);
-    print "DEC: ", $x, "\n";
-}
-
-# Encode a single unsafe word:
-$encoded = encode_mimeword("\xABFran\xE7ois\xBB");
-print "ENC1: ", $encoded, "\n";
-    
-# Encode a string, trying to find the unsafe words inside it: 
-$encoded = encode_mimewords("Me and \xABFran\xE7ois\xBB at the beach");
-print "ENC2: ", $encoded, "\n";
-
-# Encode "<<Franc,ois>>":
-my $unsafe = <<EOF;
-Me and \xABFran\xE7ois\xBB, down at the beach
-with Dave <dave\@ether.net>
-EOF
-$encoded = encode_mimewords($unsafe);
-print "ENC3: ", $encoded, "\n";
-print "DEC3: ", scalar(decode_mimewords($encoded)), "\n";
-
-# So we know everything went well...
-exit 0;
-
-#------------------------------
-
-
